{% load i18n %}
<p>
    <span class="fpe-action fpe-action-warning">{% translate "Editing content directly is disabled." %}</span>
    <strong>
        <a href="{% url 'admin:flatpages_extra_revision_add' %}?page={{ widget.page_pk }}" class="button">
            {% translate "Create a revision instead." %}
        </a>
    </strong>
    <input type="hidden" name="{{ widget.name }}" value="{{ widget.value }}">
</p>
