{% extends "admin/change_form.html" %}

{% load i18n admin_urls %}

{% block field_sets %}
    {{ original.highlighted_diff }}
{% endblock %}

{% block submit_buttons_bottom %}
    <div class="submit-row">
        <a href="{% url opts|admin_urlname:'change' original.pk|admin_urlquote %}"
           class="fpe-action fpe-action-edit button">{% translate 'Edit' %}</a>
        <a href="{% url opts|admin_urlname:'changelist' %}"
           class="fpe-action fpe-action-cancel button">{% translate 'Cancel' %}</a>
    </div>
{% endblock %}
